"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.UnorderedList = exports.OrderedList = void 0;
var _react = _interopRequireDefault(require("react"));
var _stack = _interopRequireWildcard(require("../stack/stack"));
var _icon = _interopRequireDefault(require("../icon/icon"));
var _text = _interopRequireDefault(require("../text/text"));
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && Object.prototype.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
/**
 * List is a layout component that arranges its children into a list.
 * Each child is given an equal amount of space.
 * An optional icon can be displayed next to each child.
 */
const List = /*#__PURE__*/_react.default.memo( /*#__PURE__*/_react.default.forwardRef(({
  children,
  renderIcon = undefined,
  ...props
}, ref) => {
  return /*#__PURE__*/_react.default.createElement(_stack.default, _extends({
    ref: ref
  }, props), _react.default.Children.map(children, (child, index) => /*#__PURE__*/_react.default.createElement(_stack.HStack, {
    key: index,
    spacing: "2.5"
  }, renderIcon && renderIcon(index), child)));
}));

/**
 * OrderedList is a layout component that arranges its children into an ordered list.
 */
const OrderedList = exports.OrderedList = /*#__PURE__*/_react.default.memo( /*#__PURE__*/_react.default.forwardRef(({
  children,
  ...rest
}, ref) => {
  return /*#__PURE__*/_react.default.createElement(List, _extends({}, rest, {
    renderIcon: () => /*#__PURE__*/_react.default.createElement(_icon.default, {
      iconFamily: "FontAwesome",
      iconName: "circle",
      rawSize: 6,
      mt: "2"
    }),
    ref: ref
  }), children);
}));

/**
 * UnorderedList is a layout component that arranges its children into an unordered list.
 */
const UnorderedList = exports.UnorderedList = /*#__PURE__*/_react.default.memo( /*#__PURE__*/_react.default.forwardRef(({
  children,
  ...rest
}, ref) => {
  return /*#__PURE__*/_react.default.createElement(List, _extends({}, rest, {
    renderIcon: index => /*#__PURE__*/_react.default.createElement(_text.default, {
      variant: "p4"
    }, index + 1, "."),
    ref: ref
  }), children);
}));
List.displayName = "List";
OrderedList.displayName = "OrderedList";
UnorderedList.displayName = "UnorderedList";
var _default = exports.default = List;
//# sourceMappingURL=list.js.map