"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireDefault(require("react"));
var _pearl = require("../../../pearl");
var _text = _interopRequireDefault(require("../../atoms/text/text"));
var _icon = _interopRequireDefault(require("../../atoms/icon/icon"));
var _stack = _interopRequireDefault(require("../../atoms/stack/stack"));
var _hooks = require("../../../hooks");
var _theme = require("../../../theme");
var _box = _interopRequireDefault(require("../../atoms/box/box"));
var _iconButton = _interopRequireDefault(require("../icon-button/icon-button"));
var _lodash = _interopRequireDefault(require("lodash"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
/**
 * BaseAlertProps are the properties for the BaseAlert component.
 * It extends StackProps and adds additional properties.
 */

const BaseAlert = /*#__PURE__*/_react.default.memo( /*#__PURE__*/_react.default.forwardRef(({
  atoms,
  children,
  ...rest
}, ref) => {
  let {
    icon,
    withIcon = true,
    title,
    description,
    withCloseButton = false,
    onClose = () => {},
    ...otherContainerProps
  } = atoms.container;
  const computedDescriptionStyles = (0, _hooks.useStyleProps)(atoms.description, _theme.boxStyleFunctions);
  if (!icon && withIcon) icon = /*#__PURE__*/_react.default.createElement(_icon.default, atoms.icon);
  return /*#__PURE__*/_react.default.createElement(_stack.default, _extends({}, rest, {
    ref: ref
  }, otherContainerProps, {
    accessible: true,
    accessibilityRole: "alert"
  }), icon && /*#__PURE__*/_react.default.cloneElement(icon, {
    ...atoms.icon,
    ...icon.props
  }), /*#__PURE__*/_react.default.createElement(_stack.default, atoms.stack, /*#__PURE__*/_react.default.createElement(_box.default, {
    flexDirection: "row",
    justifyContent: "space-between"
  }, title && /*#__PURE__*/_react.default.createElement(_text.default, atoms.title, title)), description && /*#__PURE__*/_react.default.createElement(_box.default, {
    style: computedDescriptionStyles.style
  }, /*#__PURE__*/_react.default.createElement(_text.default, _lodash.default.omit(computedDescriptionStyles, ["style"]), description))), withCloseButton && /*#__PURE__*/_react.default.createElement(_iconButton.default, _extends({
    position: "absolute",
    top: 5,
    right: 7,
    icon: /*#__PURE__*/_react.default.createElement(_icon.default, {
      iconFamily: "Ionicons",
      iconName: "close"
    })
  }, atoms.closeButton, {
    onPress: onClose,
    accessible: true,
    accessibilityRole: "button",
    accessibilityLabel: "Close Alert"
  })));
}));

/** Alert is used to display a short, important message in a way that attracts the user's attention without interrupting the user's task. */
const Alert = (0, _pearl.pearl)(BaseAlert, {
  componentName: "Alert",
  type: "molecule",
  animatable: true
}, undefined, {
  partForOverridenAnimationProps: "container",
  partForOverridenNativeProps: "container",
  partForOverridenStyleProps: "container"
});
Alert.displayName = "Alert";
var _default = exports.default = Alert;
//# sourceMappingURL=alert.js.map