"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _lodash = require("lodash");
var _stack = require("../../atoms/stack/stack");
var _pearl = require("../../../pearl");
var _input = _interopRequireDefault(require("../input/input"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && Object.prototype.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const BasePinInput = /*#__PURE__*/_react.default.memo( /*#__PURE__*/_react.default.forwardRef(({
  children,
  atoms
}, ref) => {
  const {
    value,
    placeholder,
    autoFocus = false,
    numFields = 4,
    manageFocus = true,
    type = "number",
    onChangeText = () => {},
    onComplete = () => {},
    spacing,
    divider,
    ...restInputProps
  } = atoms.input;
  const inputRefs = (0, _react.useRef)([]);
  const [pinValues, setPinValues] = (0, _react.useState)(Array(numFields).fill(""));

  // Use effect to handle changes in value and children props
  (0, _react.useEffect)(() => {
    // If value prop is provided, split it into individual characters and set it as pinValues
    if (value) {
      let paddedValue = value.split("");
      // If the length of the value is less than numFields, pad it with empty strings
      while (paddedValue.length < numFields) {
        paddedValue.push("");
      }
      setPinValues(paddedValue);
    }

    // If children prop is provided and it is an array, adjust the length of inputRefs accordingly
    if (children && (0, _lodash.isArray)(children)) inputRefs.current = inputRefs.current.slice(0, children.length);
  }, [children, value]); // Depend on children and value props

  // Function to handle text changes in the input fields
  const handleOnChangeText = (index, value) => {
    // Update the value at the current index
    let newPinValues = [...pinValues];
    // If the type is "number" and the value is not a number, return without making changes
    if (type === "number" && Number.isNaN(Number(value))) return;
    newPinValues[index] = value;

    // If the value becomes "", then replace the pinValues value with "" at the index
    if (value === "") newPinValues[index] = "";

    // Update the state with the new pin values
    setPinValues(newPinValues);

    // If all input fields have values, call the onComplete function
    if (newPinValues.every(val => val !== "")) {
      onComplete(newPinValues.join(""));
    }

    // If an onChangeText function is provided, call it with the current pin values
    onChangeText(newPinValues.join(""));

    // If the value becomes "", and there is a previous input field, focus it
    if (value === "" && inputRefs.current[index - 1] && manageFocus) {
      inputRefs.current[index - 1].focus();
    }

    // If the value is a valid value and there is a next input field, focus it
    else if (value !== "" && inputRefs.current[index + 1] && manageFocus && (type !== "number" || type === "number" && !Number.isNaN(Number(value)))) {
      inputRefs.current[index + 1].focus();
    }
  };

  // Function to handle key press events in the input fields
  const handleOnKeyPress = (index, event) => {
    // If the pressed key is "Backspace", the current field is empty, and there is a previous field, focus the previous field
    if (event.nativeEvent.key === "Backspace" && pinValues[index] === "" && inputRefs.current[index - 1] && manageFocus) {
      inputRefs.current[index - 1].focus();
    }
    // If the pressed key is not "Backspace", the current field is not empty, the next field is empty, and there is a next field, focus the next field
    else if (event.nativeEvent.key !== "Backspace" && pinValues[index] !== "" && pinValues[index + 1] === "" && inputRefs.current[index + 1] && manageFocus) {
      inputRefs.current[index + 1].focus();
    }
  };
  return /*#__PURE__*/_react.default.createElement(_stack.HStack, _extends({
    ref: ref,
    spacing: spacing,
    divider: divider
  }, atoms.container), [...Array(numFields).keys()].map(fieldIdx => {
    return /*#__PURE__*/_react.default.createElement(_input.default, _extends({
      maxLength: 1,
      key: fieldIdx,
      inputMode: type === "number" ? "numeric" : "none",
      autoFocus: !!autoFocus && fieldIdx === 0 ? true : false
    }, restInputProps, {
      placeholder: "O",
      ref: el => inputRefs.current[fieldIdx] = el,
      onChangeText: value => handleOnChangeText(fieldIdx, value),
      onKeyPress: event => handleOnKeyPress(fieldIdx, event),
      value: pinValues[fieldIdx]
    }));
  }));
}));

/**
 * Similar to the Input component, but is optimized for entering sequences of digits quickly.
 */
const PinInput = (0, _pearl.pearl)(BasePinInput, {
  componentName: "PinInput",
  type: "molecule",
  animatable: true
}, undefined, {
  partForOverridenStyleProps: "container",
  partForOverridenNativeProps: "input",
  partForOverridenAnimationProps: "container"
});
PinInput.displayName = "PinInput";
var _default = exports.default = PinInput;
//# sourceMappingURL=pin-input.js.map